# Reference Plugins

This directory is intended to contain reference plugins that can be used as inspiration for development. These plugins are not part of the actual plugin but serve as examples of best practices and implementation patterns.

## Recommended Reference Plugins

1. **[Fix 'Plugin file does not exist' Notices](https://github.com/wpallstars/wp-fix-plugin-does-not-exist-notices)**
   - This plugin is the original inspiration for this starter template
   - Demonstrates clean, modular code structure
   - Shows implementation of Git Updater integration
   - Provides examples of WordPress admin UI integration

2. **[WordPress Plugin Boilerplate](https://github.com/devinvinson/WordPress-Plugin-Boilerplate)**
   - A standardized, organized, object-oriented foundation for building high-quality WordPress plugins
   - Follows WordPress coding standards
   - Provides a clear separation of concerns

3. **[CMB2](https://github.com/CMB2/CMB2)**
   - Excellent example of metabox and form handling
   - Well-documented codebase
   - Demonstrates extensibility and API design

4. **[WooCommerce](https://github.com/woocommerce/woocommerce)**
   - Example of a large-scale WordPress plugin
   - Demonstrates advanced features like custom post types, taxonomies, and REST API integration
   - Shows how to structure a complex plugin

## How to Use Reference Plugins

1. **Study the Code Structure**:
   - Examine how the plugin is organized
   - Note the separation of concerns
   - Observe naming conventions and coding standards

2. **Analyze Implementation Patterns**:
   - Look at how common WordPress patterns are implemented
   - Study how the plugin integrates with WordPress hooks
   - Observe error handling and security practices

3. **Adapt, Don't Copy**:
   - Use these plugins as inspiration, not as code to copy directly
   - Adapt patterns to fit your specific needs
   - Ensure you understand the code before using similar approaches

## Adding Reference Plugins

To add a reference plugin to this directory:

1. Create a subdirectory with the plugin name
2. Include a README.md file explaining why this plugin is included as a reference
3. Add relevant code snippets or links to the original repository
4. Update this README.md file to include the new reference plugin

## Note on Licensing

When using code from reference plugins, always respect their licensing terms. Most WordPress plugins are licensed under GPL or compatible licenses, but always verify before using any code.
